==> jc-1.4.0.tar.gz: gnu/classpath/ServiceFactory.h <==
// public final class gnu.classpath.ServiceFactory

// class file dependencies
// @dep_class 3b1b87fb64290f63 gnu_classpath_ServiceFactory
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_ServiceFactory_H_
#define _JC_gnu_classpath_ServiceFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_logging_Level$object;
struct _jc_java_util_logging_Logger$object;

// Typedefs
typedef struct _jc_gnu_classpath_ServiceFactory$sub_refs	_jc_gnu_classpath_ServiceFactory$sub_refs;
typedef struct _jc_gnu_classpath_ServiceFactory$sub_nonrefs	_jc_gnu_classpath_ServiceFactory$sub_nonrefs;
typedef struct _jc_gnu_classpath_ServiceFactory$refs	_jc_gnu_classpath_ServiceFactory$refs;
typedef struct _jc_gnu_classpath_ServiceFactory$nonrefs	_jc_gnu_classpath_ServiceFactory$nonrefs;
typedef struct _jc_gnu_classpath_ServiceFactory$object	_jc_gnu_classpath_ServiceFactory$object;

typedef struct _jc_gnu_classpath_ServiceFactory$fields_struct	_jc_gnu_classpath_ServiceFactory$fields_struct;
typedef const struct _jc_gnu_classpath_ServiceFactory$vmethods	_jc_gnu_classpath_ServiceFactory$vmethods;
typedef const struct _jc_gnu_classpath_ServiceFactory$vtable	_jc_gnu_classpath_ServiceFactory$vtable;
typedef const struct _jc_gnu_classpath_ServiceFactory$vtype	_jc_gnu_classpath_ServiceFactory$vtype;

// Class fields structure
struct _jc_gnu_classpath_ServiceFactory$fields_struct {
	struct _jc_java_util_logging_Logger$object	*LOGGER;
	struct _jc_java_lang_Class$object	*class__24gnu__24classpath__24ServiceFactory;
};
extern _jc_gnu_classpath_ServiceFactory$fields_struct _jc_gnu_classpath_ServiceFactory$class_fields;

// Constructors
extern void _jc_gnu_classpath_ServiceFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_ServiceFactory$object *);

// Static methods
extern void _jc_gnu_classpath_ServiceFactory$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_classpath_ServiceFactory$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_gnu_classpath_ServiceFactory$method$log$e235f30052210353(_jc_env *, struct _jc_java_util_logging_Level$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Throwable$object *);
extern struct _jc_object *_jc_gnu_classpath_ServiceFactory$method$lookupProviders$39853a0ed089b14a(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_gnu_classpath_ServiceFactory$method$lookupProviders$4e87552e2e8d62f4(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods structure
struct _jc_gnu_classpath_ServiceFactory$vmethods {
};

// Vtable
struct _jc_gnu_classpath_ServiceFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_ServiceFactory$vmethods	gnu_classpath_ServiceFactory;
};

// Vtype
struct _jc_gnu_classpath_ServiceFactory$vtype {
	_jc_type			type;
	_jc_gnu_classpath_ServiceFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_ServiceFactory$refs {
    _jc_gnu_classpath_ServiceFactory$sub_refs	gnu_classpath_ServiceFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_ServiceFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_ServiceFactory$sub_nonrefs	gnu_classpath_ServiceFactory;
};

// Object instance structure
struct _jc_gnu_classpath_ServiceFactory$object {
	_jc_gnu_classpath_ServiceFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_ServiceFactory$vtype	*vtype;
	_jc_gnu_classpath_ServiceFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_ServiceFactory$vtype _jc_gnu_classpath_ServiceFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_ServiceFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_ServiceFactory$class_object;

#endif	/* _JC_gnu_classpath_ServiceFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/classpath/ServiceFactory.h <==
// public final class gnu.classpath.ServiceFactory

// class file dependencies
// @dep_class 3b1b87fb64290f63 gnu_classpath_ServiceFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_ServiceFactory_H_
#define _JC_gnu_classpath_ServiceFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_logging_Level$object;
struct _jc_java_util_logging_Logger$object;

// Typedefs
typedef struct _jc_gnu_classpath_ServiceFactory$sub_refs	_jc_gnu_classpath_ServiceFactory$sub_refs;
typedef struct _jc_gnu_classpath_ServiceFactory$sub_nonrefs	_jc_gnu_classpath_ServiceFactory$sub_nonrefs;
typedef struct _jc_gnu_classpath_ServiceFactory$refs	_jc_gnu_classpath_ServiceFactory$refs;
typedef struct _jc_gnu_classpath_ServiceFactory$nonrefs	_jc_gnu_classpath_ServiceFactory$nonrefs;
typedef struct _jc_gnu_classpath_ServiceFactory$object	_jc_gnu_classpath_ServiceFactory$object;

typedef struct _jc_gnu_classpath_ServiceFactory$fields_struct	_jc_gnu_classpath_ServiceFactory$fields_struct;
typedef const struct _jc_gnu_classpath_ServiceFactory$vmethods	_jc_gnu_classpath_ServiceFactory$vmethods;
typedef const struct _jc_gnu_classpath_ServiceFactory$vtable	_jc_gnu_classpath_ServiceFactory$vtable;
typedef const struct _jc_gnu_classpath_ServiceFactory$vtype	_jc_gnu_classpath_ServiceFactory$vtype;

// Class fields structure
struct _jc_gnu_classpath_ServiceFactory$fields_struct {
	struct _jc_java_util_logging_Logger$object	*LOGGER;
	struct _jc_java_lang_Class$object	*class__24gnu__24classpath__24ServiceFactory;
};
extern _jc_gnu_classpath_ServiceFactory$fields_struct _jc_gnu_classpath_ServiceFactory$class_fields;

// Constructors
extern void _jc_gnu_classpath_ServiceFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_classpath_ServiceFactory$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_classpath_ServiceFactory$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_classpath_ServiceFactory$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_gnu_classpath_ServiceFactory$method$log$e235f30052210353(_jc_env *, struct _jc_java_util_logging_Level$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_classpath_ServiceFactory$method$lookupProviders$39853a0ed089b14a(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_classpath_ServiceFactory$method$lookupProviders$4e87552e2e8d62f4(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_classpath_ServiceFactory$vmethods {
};

// Vtable
struct _jc_gnu_classpath_ServiceFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_ServiceFactory$vmethods	gnu_classpath_ServiceFactory;
};

// Vtype
struct _jc_gnu_classpath_ServiceFactory$vtype {
	_jc_type			type;
	_jc_gnu_classpath_ServiceFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_classpath_ServiceFactory$refs {
    _jc_gnu_classpath_ServiceFactory$sub_refs	gnu_classpath_ServiceFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_ServiceFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_ServiceFactory$sub_nonrefs	gnu_classpath_ServiceFactory;
};

// Object instance structure
struct _jc_gnu_classpath_ServiceFactory$object {
	_jc_gnu_classpath_ServiceFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_ServiceFactory$vtype	*vtype;
	_jc_gnu_classpath_ServiceFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_ServiceFactory$vtype _jc_gnu_classpath_ServiceFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_ServiceFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_ServiceFactory$class_object;

#endif	/* _JC_gnu_classpath_ServiceFactory_H_ */
